@@ -23,7 +23,9 @@ import sys
 import os
 import yaml
 import logging
-from jinja2 import Environment, Undefined, DebugUndefined,StrictUndefined
+from jinja2 import Environment, Undefined, DebugUndefined, StrictUndefined, TemplateError
+
+from . import odyldo
 
 __all__ = [
     'load',
@@ -38,6 +40,7 @@ __version__ = version.VERSION
 
 logger = logging.getLogger(__name__)
 
+_usedefaultyamlloader = False
 
 class HiYaPyCoInvocationException(Exception):
     """dummy Exception raised on wrong invocation"""
@@ -65,6 +68,19 @@ METHOD_MERGE = METHODS['METHOD_MERGE']
 class HiYaPyCo():
     """Main class"""
     def __init__(self, *args, **kwargs):
+        """
+        args: YAMLfile(s)
+        kwargs:
+          * method: one of hiyapyco.METHOD_SIMPLE | hiyapyco.METHOD_MERGE
+          * interpolate: boolean (default: False)
+          * usedefaultyamlloader: boolean (default: False)
+          * loglevel: one of  the valid levels from the logging module
+          * failonmissingfiles: boolean (default: True)
+          * loglevelmissingfiles
+
+        Returns a representation of the merged and (if requested) interpolated config.
+        Will mostly be a OrderedDict (dict if usedefaultyamlloader), but can be of any other type, depending on the yaml files.
+        """
         self._data = None
         self._files = []
 
@@ -86,6 +102,11 @@ class HiYaPyCo():
             self.interpolate = kwargs['interpolate']
             del kwargs['interpolate']
 
+        if 'usedefaultyamlloader' in kwargs:
+            global _usedefaultyamlloader
+            _usedefaultyamlloader = kwargs['usedefaultyamlloader']
+            del kwargs['usedefaultyamlloader']
+
         self.failonmissingfiles = True
         if 'failonmissingfiles' in kwargs:
             self.failonmissingfiles = bool(kwargs['failonmissingfiles'])
@@ -127,7 +148,10 @@ class HiYaPyCo():
                     logger.log(self.loglevelonmissingfiles, 'file not found: %s' % yamlfile)
                 if self.failonmissingfiles:
                     raise HiYaPyCoInvocationException('yaml file not found: \'%s\'' % yamlfile )
-            ydata = yaml.safe_load(f)
+            if _usedefaultyamlloader:
+                ydata = yaml.safe_load(f)
+            else:
+                ydata = odyldo.safe_load(f)
             if logger.isEnabledFor(logging.DEBUG):
                 logger.debug('yaml data: %s' % ydata)
             if self._data is None:
@@ -173,7 +197,10 @@ class HiYaPyCo():
         raise HiYaPyCoImplementationException('can not interpolate "%s" of type %s' % (d, type(d),))
 
     def _interpolatestr(self, s):
-        si = jinja2env.from_string(s).render(self._data)
+        try:
+            si = jinja2env.from_string(s).render(self._data)
+        except TemplateError as e:
+            raise HiYaPyCoImplementationException('error interpolating string "%s" : %s' % (s, e,))
         if not s == si:
             logger.debug('interpolated "%s" to "%s"' % (s, si,))
         return si
@@ -302,7 +329,10 @@ class HiYaPyCo():
 
 def dump(data, default_flow_style = False):
     """dump the data as YAML"""
-    return yaml.safe_dump(data, default_flow_style = default_flow_style)
+    if _usedefaultyamlloader:
+        return yaml.safe_dump(data, default_flow_style = default_flow_style)
+    else:
+        return odyldo.safe_dump(data, default_flow_style = default_flow_style)
 
 def load(*args, **kwargs):
     """
@@ -310,10 +340,16 @@ def load(*args, **kwargs):
     --------------------------------------
 
     args: YAMLfile(s)
-    kwargs: method, interpolate, loglevel, failonmissingfiles, loglevelmissingfiles
+    kwargs:
+      * method: one of hiyapyco.METHOD_SIMPLE | hiyapyco.METHOD_MERGE
+      * interpolate: boolean (default: False)
+      * usedefaultyamlloader: boolean (default: False)
+      * loglevel: one of  the valid levels from the logging module
+      * failonmissingfiles: boolean (default: True)
+      * loglevelmissingfiles
 
     Returns a representation of the merged and (if requested) interpolated config.
-    Will mostly be a dict, but can be of any other type, depending on the yaml files.
+    Will mostly be a OrderedDict (dict if usedefaultyamlloader), but can be of any other type, depending on the yaml files.
     """
     hiyapyco = HiYaPyCo(*args, **kwargs)
     return hiyapyco.data()
